/*
 * Copyright (c) 2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

/*!
 * @header CAttributeList
 */

#ifndef __CAttributeList_h__
#define __CAttributeList_h__		1

#include <stdio.h>
#include <stdlib.h>
#include <DirectoryServiceCore/PrivateTypes.h>

class CAttributeList {
public:
		   			CAttributeList			( tDataListPtr inNodeList );
		   			CAttributeList			( char *inNode );
	virtual		   ~CAttributeList			( void );

	uInt32			GetCount				( void );
	sInt32			GetAttribute			( uInt32 inIndex, char **outData );

protected:


private:
	tDataListPtr	fNodeList;
	bool			bCleanData;
};

#endif
